# -*- coding: utf-8 -*-
#
# Configuration file for the Sphinx documentation builder.
#
# This file does only contain a selection of the most common options. For a
# full list see the documentation:
# http://www.sphinx-doc.org/en/master/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

try:
    from sphinx_astropy.conf.v1 import *  # noqa
except ImportError:
    print(
        "ERROR: the documentation requires the sphinx-astropy package to be installed"
    )
    sys.exit(1)

sys.path.insert(0, os.path.abspath(".."))

import mocpy

# -- Project information -----------------------------------------------------

# Get configuration information from setup.cfg
import tomllib

with open("../Cargo.toml", "rb") as config:
    cargotoml = tomllib.load(config)
import datetime

project = cargotoml["package"]["name"]
author = " ".join(cargotoml["package"]["authors"])

copyright = f"{datetime.datetime.now().year}, {author}"

# The short X.Y version
version = mocpy.__version__
# The full version, including alpha/beta/rc tags
release = mocpy.__version__


# -- General configuration ---------------------------------------------------


# By default, highlight as Python 3.
highlight_language = "python3"


# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    "sphinx.ext.intersphinx",
    "sphinx.ext.viewcode",
    "sphinxcontrib.bibtex",
    "sphinxcontrib.collections",
    # Extension for plotting image in the doc
    "matplotlib.sphinxext.plot_directive",
    # To support Numpy docstrings, we use this extension:
    # see https://numpydoc.readthedocs.io/en/latest/install.html
    "numpydoc",
    # "jupyter_sphinx",
    "nbsphinx",
    "sphinx_copybutton",
    "sphinx_gallery.load_style",
]
bibtex_bibfiles = ["references.bib"]

default_role = "py:obj"
numpydoc_class_members_toctree = False
numpydoc_show_class_members = False
autosummary_generate = False

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path .
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "bootstrap-astropy"
html_show_sphinx = False

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see theZXing library
# documentation.
#
html_theme_options = {
    "logotext1": "MOC",  # white,  semi-bold
    "logotext2": "py",  # orange, light
    "logotext3": ":docs",  # white,  light
    "astropy_project_menubar": False,
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ['_static']
# No static so far
html_static_path = ["_static"]  # html_theme = None
html_style = "mocpy.css"

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
html_favicon = "_static/MOCpy-icon.svg"

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# The default sidebars (for documents that don't match any pattern) are
# defined by theme itself.  Builtin themes are using these templates by
# default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
# 'searchbox.html']``.
#
# html_sidebars = {}

# -- Add the notebooks to Sphinx root folder with collections ----------------

collections = {
    "notebooks": {
        "driver": "copy_folder",
        "source": "../notebooks/",
        "target": "notebooks",
        "ignore": [".fits", ".ipynb_checkpoints/*"],
    }
}

# -- Configuration for nbsphinx ----------------------------------------------

nbsphinx_allow_errors = True


# -- Options for HTMLHelp output ---------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "mocpydoc"

# Prefixes that are ignored for sorting the Python module index
modindex_common_prefix = ["mocpy."]


# -- Options for LaTeX output ------------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',
    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',
    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (
        master_doc,
        "mocpy.tex",
        "mocpy Documentation",
        author,
        "manual",
    ),
]


# -- Options for manual page output ------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "mocpy", "mocpy Documentation", [author], 1)]


# -- Options for Texinfo output ----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "mocpy",
        "mocpy Documentation",
        author,
        "mocpy",
        "A python packages to handle MOCs.",
        "Miscellaneous",
    ),
]


# -- Extension configuration -------------------------------------------------

# -- Options for intersphinx extension ---------------------------------------

# Include other packages to link against

intersphinx_mapping = {
    "python": ("https://docs.python.org/", None),
    "astropy": ("http://docs.astropy.org/en/latest/", None),
    "matplotlib": ("https://matplotlib.org/", None),
    "networkx": ("https://networkx.github.io/documentation/stable/", None),
    "numpy": ("https://numpy.org/doc/stable/", None),
}


def setup(app):
    pass
